@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -24,6 +24,8 @@ package com.openexchange.admin.reseller.console;
 import java.rmi.RemoteException;
 import java.util.ArrayList;
 import java.util.Arrays;
+import java.util.Map;
+import java.util.Set;
 import com.openexchange.admin.console.AdminParser;
 import com.openexchange.admin.reseller.rmi.OXResellerInterface;
 import com.openexchange.admin.reseller.rmi.dataobjects.ResellerAdmin;
@@ -39,26 +41,27 @@ import com.openexchange.admin.rmi.exceptions.StorageException;
  */
 public class List extends ResellerAbstraction {
 
-    protected final void setOptions(final AdminParser parser) {
+    protected final void setOptions(AdminParser parser) {
         setDefaultCommandLineOptionsWithoutContextID(parser);
         setCSVOutputOption(parser);
     }
 
     /**
-     *
+     * Initializes a new {@link List}.
      */
     public List() {
+        super();
     }
 
     /**
      * @param args
      */
-    public static void main(final String[] args) {
+    public static void main(String[] args) {
         final List list = new List();
         list.start(args);
     }
 
-    public void start(final String[] args) {
+    public void start(String[] args) {
         final AdminParser parser = new AdminParser("listadmin");
 
         setOptions(parser);
@@ -95,17 +98,17 @@ public class List extends ResellerAbstraction {
         }
     }
 
-    private void sysoutOutput(final java.util.List<ResellerAdmin> admns) throws InvalidDataException {
+    private void sysoutOutput(java.util.List<ResellerAdmin> admns) throws InvalidDataException {
         final ArrayList<ArrayList<String>> data = new ArrayList<ArrayList<String>>();
         for (final ResellerAdmin admin : admns) {
-            data.add(makeStandardData(admin));
+            data.add(makeStandardData(admin, false));
         }
 
         // doOutput(new String[] { "3r", "30l", "30l", "14l" },
         doOutput(new String[] { "r", "l", "l", "l", "l" }, new String[] { "Id", "Name", "Displayname", "Parent", "Restrictions" }, data);
     }
 
-    private void precsvinfos(final java.util.List<ResellerAdmin> adminlist) throws InvalidDataException {
+    private void precsvinfos(java.util.List<ResellerAdmin> adminlist) throws InvalidDataException {
         // needed for csv output, KEEP AN EYE ON ORDER!!!
         final ArrayList<String> columns = new ArrayList<String>();
         columns.add("id");
@@ -113,6 +116,8 @@ public class List extends ResellerAbstraction {
         columns.add("displayname");
         columns.add("parentid");
         columns.add("restrictions");
+        columns.add("capabilities");
+        columns.add("configuration");
 
         // Needed for csv output
         final ArrayList<ArrayList<String>> data = new ArrayList<ArrayList<String>>();
@@ -135,13 +140,13 @@ public class List extends ResellerAbstraction {
      * @throws StorageException
      * @throws InvalidDataException
      */
-    private ArrayList<String> makeDataForCsv(final ResellerAdmin admin) {
-        final ArrayList<String> admin_data = makeStandardData(admin);
+    private ArrayList<String> makeDataForCsv(ResellerAdmin admin) {
+        final ArrayList<String> admin_data = makeStandardData(admin, true);
 
         return admin_data;
     }
 
-    private ArrayList<String> makeStandardData(final ResellerAdmin admin) {
+    private ArrayList<String> makeStandardData(ResellerAdmin admin, boolean csv) {
         final ArrayList<String> admin_data = new ArrayList<String>();
 
         admin_data.add(String.valueOf(admin.getId())); // id
@@ -165,6 +170,20 @@ public class List extends ResellerAbstraction {
         } else {
             admin_data.add("");
         }
+        if (csv) {
+            Set<String> capabilities = admin.getCapabilities();
+            if (null != capabilities) {
+                admin_data.add(ResellerAbstraction.getCollectionAsString(capabilities)); // restrictions
+            } else {
+                admin_data.add("");
+            }
+            Map<String, String> configuration = admin.getConfiguration();
+            if (null != configuration) {
+                admin_data.add(ResellerAbstraction.getMapAsString(configuration)); // restrictions
+            } else {
+                admin_data.add("");
+            }
+        }
         return admin_data;
     }
 
