@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -29,6 +29,7 @@ import java.util.Collection;
 import java.util.Collections;
 import java.util.HashMap;
 import java.util.HashSet;
+import java.util.Iterator;
 import java.util.Map;
 import java.util.Optional;
 import java.util.Map.Entry;
@@ -310,7 +311,7 @@ public abstract class ResellerAbstraction extends ObjectNamingAbstraction {
         if (opt.indexOf('=') < 0) {
             throw new InvalidDataException("Restriction must be key=value pair");
         }
-        String[] keyval = opt.split("=");
+        String[] keyval = Strings.splitBy(opt, '=', true);
         if (keyval.length > 2) {
             throw new InvalidDataException("Restriction must only contain one \"=\" character");
         }
@@ -363,7 +364,7 @@ public abstract class ResellerAbstraction extends ObjectNamingAbstraction {
             }
         }
         // Split
-        String[] arr = s.split(" *, *", 0);
+        String[] arr = Strings.splitByComma(s);
         Set<String> set = new HashSet<>(arr.length);
         for (String element : arr) {
             String cap = element;
@@ -528,9 +529,53 @@ public abstract class ResellerAbstraction extends ObjectNamingAbstraction {
         return sb.toString();
     }
 
+    /**
+     * This method takes a collection of objects and format them to one comma-separated string
+     *
+     * @param objects
+     * @return
+     */
+    public static <O> String getCollectionAsString(Collection<O> objects) {
+        if (null == objects || objects.isEmpty()) {
+            return "";
+        }
+        StringBuilder sb = new StringBuilder();
+        Iterator<O> it = objects.iterator();
+        if (it.hasNext()) {
+            sb.append(it.next());
+            while (it.hasNext()) {
+                sb.append(',').append(it.next());
+            }
+        }
+        return sb.toString();
+    }
+
+    /**
+     * This method takes a map and formats it to one comma-separated string
+     *
+     * @param map
+     * @return
+     */
+    public static <K, V> String getMapAsString(Map<K, V> map) {
+        if (null == map || map.isEmpty()) {
+            return "";
+        }
+        StringBuilder sb = new StringBuilder();
+        Iterator<Map.Entry<K, V>> it = map.entrySet().iterator();
+        if (it.hasNext()) {
+            Map.Entry<K, V> entry = it.next();
+            sb.append(entry.getKey()).append('=').append(entry.getValue());
+            while (it.hasNext()) {
+                entry = it.next();
+                sb.append(',').append(entry.getKey()).append('=').append(entry.getValue());
+            }
+        }
+        return sb.toString();
+    }
+
     /**
      * Applies the dynamic options of configuration and taxonomies to the specified {@link ResellerAdmin}
-     * 
+     *
      * @param parser the {@link AdminParser}
      * @param adm The {@link ResellerAdmin}
      */
@@ -556,7 +601,7 @@ public abstract class ResellerAbstraction extends ObjectNamingAbstraction {
 
     /**
      * Processes the specified dynamic argument
-     * 
+     *
      * @param namespaced The dynamic argument
      * @param configToAdd The config to add
      * @param configToRemove The config to remove
